==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/naq.pl <==
{
  am_pm_abbreviated => [
    "\N{U+01c1}goagas",
    "\N{U+01c3}uias",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "naq",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Ma",
    "De",
    "Wu",
    "Do",
    "Fr",
    "Sat",
    "Son",
  ],
  day_format_narrow => [
    "M",
    "E",
    "W",
    "D",
    "F",
    "A",
    "S",
  ],
  day_format_wide => [
    "Mantaxtsees",
    "Denstaxtsees",
    "Wunstaxtsees",
    "Dondertaxtsees",
    "Fraitaxtsees",
    "Satertaxtsees",
    "Sontaxtsees",
  ],
  day_stand_alone_abbreviated => [
    "Ma",
    "De",
    "Wu",
    "Do",
    "Fr",
    "Sat",
    "Son",
  ],
  day_stand_alone_narrow => [
    "M",
    "E",
    "W",
    "D",
    "F",
    "A",
    "S",
  ],
  day_stand_alone_wide => [
    "Mantaxtsees",
    "Denstaxtsees",
    "Wunstaxtsees",
    "Dondertaxtsees",
    "Fraitaxtsees",
    "Satertaxtsees",
    "Sontaxtsees",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Xristub ai\N{U+01c3}\N{U+00e2}",
    "Xristub khao\N{U+01c3}g\N{U+00e2}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Nama",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "May",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Oct",
    "Nov",
    "Dec",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "\N{U+01c3}Khanni",
    "\N{U+01c3}Khan\N{U+01c0}g\N{U+00f4}ab",
    "\N{U+01c0}Khuu\N{U+01c1}kh\N{U+00e2}b",
    "\N{U+01c3}H\N{U+00f4}a\N{U+01c2}khaib",
    "\N{U+01c3}Khaits\N{U+00e2}b",
    "Gama\N{U+01c0}aeb",
    "\N{U+01c2}Khoesaob",
    "Ao\N{U+01c1}khuum\N{U+00fb}\N{U+01c1}kh\N{U+00e2}b",
    "Tara\N{U+01c0}khuum\N{U+00fb}\N{U+01c1}kh\N{U+00e2}b",
    "\N{U+01c2}N\N{U+00fb}\N{U+01c1}n\N{U+00e2}iseb",
    "\N{U+01c0}Hoo\N{U+01c2}gaeb",
    "H\N{U+00f4}asore\N{U+01c1}kh\N{U+00e2}b",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "May",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Oct",
    "Nov",
    "Dec",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "\N{U+01c3}Khanni",
    "\N{U+01c3}Khan\N{U+01c0}g\N{U+00f4}ab",
    "\N{U+01c0}Khuu\N{U+01c1}kh\N{U+00e2}b",
    "\N{U+01c3}H\N{U+00f4}a\N{U+01c2}khaib",
    "\N{U+01c3}Khaits\N{U+00e2}b",
    "Gama\N{U+01c0}aeb",
    "\N{U+01c2}Khoesaob",
    "Ao\N{U+01c1}khuum\N{U+00fb}\N{U+01c1}kh\N{U+00e2}b",
    "Tara\N{U+01c0}khuum\N{U+00fb}\N{U+01c1}kh\N{U+00e2}b",
    "\N{U+01c2}N\N{U+00fb}\N{U+01c1}n\N{U+00e2}iseb",
    "\N{U+01c0}Hoo\N{U+01c2}gaeb",
    "H\N{U+00f4}asore\N{U+01c1}kh\N{U+00e2}b",
  ],
  name => "Nama",
  native_language => "Khoekhoegowab",
  native_name => "Khoekhoegowab",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "KW1",
    "KW2",
    "KW3",
    "KW4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1ro kwartals",
    "2\N{U+01c1}\N{U+00ee} kwartals",
    "3\N{U+01c1}\N{U+00ee} kwartals",
    "4\N{U+01c1}\N{U+00ee} kwartals",
  ],
  quarter_stand_alone_abbreviated => [
    "KW1",
    "KW2",
    "KW3",
    "KW4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1ro kwartals",
    "2\N{U+01c1}\N{U+00ee} kwartals",
    "3\N{U+01c1}\N{U+00ee} kwartals",
    "4\N{U+01c1}\N{U+00ee} kwartals",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/naq.pl <==
{
  am_pm_abbreviated => [
    "\N{U+01c1}goagas",
    "\N{U+01c3}uias",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "naq",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Ma",
    "De",
    "Wu",
    "Do",
    "Fr",
    "Sat",
    "Son",
  ],
  day_format_narrow => [
    "M",
    "E",
    "W",
    "D",
    "F",
    "A",
    "S",
  ],
  day_format_wide => [
    "Mantaxtsees",
    "Denstaxtsees",
    "Wunstaxtsees",
    "Dondertaxtsees",
    "Fraitaxtsees",
    "Satertaxtsees",
    "Sontaxtsees",
  ],
  day_stand_alone_abbreviated => [
    "Ma",
    "De",
    "Wu",
    "Do",
    "Fr",
    "Sat",
    "Son",
  ],
  day_stand_alone_narrow => [
    "M",
    "E",
    "W",
    "D",
    "F",
    "A",
    "S",
  ],
  day_stand_alone_wide => [
    "Mantaxtsees",
    "Denstaxtsees",
    "Wunstaxtsees",
    "Dondertaxtsees",
    "Fraitaxtsees",
    "Satertaxtsees",
    "Sontaxtsees",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Xristub ai\N{U+01c3}\N{U+00e2}",
    "Xristub khao\N{U+01c3}g\N{U+00e2}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Nama",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "May",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Oct",
    "Nov",
    "Dec",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "\N{U+01c3}Khanni",
    "\N{U+01c3}Khan\N{U+01c0}g\N{U+00f4}ab",
    "\N{U+01c0}Khuu\N{U+01c1}kh\N{U+00e2}b",
    "\N{U+01c3}H\N{U+00f4}a\N{U+01c2}khaib",
    "\N{U+01c3}Khaits\N{U+00e2}b",
    "Gama\N{U+01c0}aeb",
    "\N{U+01c2}Khoesaob",
    "Ao\N{U+01c1}khuum\N{U+00fb}\N{U+01c1}kh\N{U+00e2}b",
    "Tara\N{U+01c0}khuum\N{U+00fb}\N{U+01c1}kh\N{U+00e2}b",
    "\N{U+01c2}N\N{U+00fb}\N{U+01c1}n\N{U+00e2}iseb",
    "\N{U+01c0}Hoo\N{U+01c2}gaeb",
    "H\N{U+00f4}asore\N{U+01c1}kh\N{U+00e2}b",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "May",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Oct",
    "Nov",
    "Dec",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "\N{U+01c3}Khanni",
    "\N{U+01c3}Khan\N{U+01c0}g\N{U+00f4}ab",
    "\N{U+01c0}Khuu\N{U+01c1}kh\N{U+00e2}b",
    "\N{U+01c3}H\N{U+00f4}a\N{U+01c2}khaib",
    "\N{U+01c3}Khaits\N{U+00e2}b",
    "Gama\N{U+01c0}aeb",
    "\N{U+01c2}Khoesaob",
    "Ao\N{U+01c1}khuum\N{U+00fb}\N{U+01c1}kh\N{U+00e2}b",
    "Tara\N{U+01c0}khuum\N{U+00fb}\N{U+01c1}kh\N{U+00e2}b",
    "\N{U+01c2}N\N{U+00fb}\N{U+01c1}n\N{U+00e2}iseb",
    "\N{U+01c0}Hoo\N{U+01c2}gaeb",
    "H\N{U+00f4}asore\N{U+01c1}kh\N{U+00e2}b",
  ],
  name => "Nama",
  native_language => "Khoekhoegowab",
  native_name => "Khoekhoegowab",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "KW1",
    "KW2",
    "KW3",
    "KW4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1ro kwartals",
    "2\N{U+01c1}\N{U+00ee} kwartals",
    "3\N{U+01c1}\N{U+00ee} kwartals",
    "4\N{U+01c1}\N{U+00ee} kwartals",
  ],
  quarter_stand_alone_abbreviated => [
    "KW1",
    "KW2",
    "KW3",
    "KW4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1ro kwartals",
    "2\N{U+01c1}\N{U+00ee} kwartals",
    "3\N{U+01c1}\N{U+00ee} kwartals",
    "4\N{U+01c1}\N{U+00ee} kwartals",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => "44.1",
}
